SystemOrganization addCategory: #ConfigurationOfSomethingIt!

Object subclass: #ConfigurationOfSomethingIt
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSomethingIt'!

!ConfigurationOfSomethingIt commentStamp: '<historical>' prior: 0!
OSProcess provides access to operating system functions, including pipes and child process creation. It is implemented using pluggable primitives in a shared library for Unix or Linux, and a DLL for Windows. The Smalltalk code, including the classes which implement pluggable primitives for Unix or Win32 operating system functions, may be loaded into any Squeak image, but the primitives are only useful on Unix and Windows systems. Placeholder classes are provided for MacOS, OS/2 and RiscOS, but are not yet implemented.!

!ConfigurationOfSomethingIt class methodsFor: 'private' stamp: 'TO 10/19/2012 14:11'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfSomethingIt class methodsFor: 'private' stamp: 'TO 10/19/2012 14:11'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.15"
			self bootstrapPackage: 'Gofer-lr.83' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfSomethingIt class methodsFor: 'metacello tool support' stamp: 'TO 10/19/2012 14:11'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSomethingIt class methodsFor: 'metacello tool support' stamp: 'TO 10/19/2012 14:11'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfSomethingIt class methodsFor: 'loading' stamp: 'TO 10/19/2012 14:11'!
load
	"self load"

	| r |
	r := self project latestVersion load.
	(Smalltalk at: #ThisOSProcess) ifNotNilDo: [ :osp | osp startUp: true ] "initialize"! !

!ConfigurationOfSomethingIt class methodsFor: 'metacello tool support' stamp: 'TO 10/19/2012 14:11'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfSomethingIt class methodsFor: 'accessing' stamp: 'TO 10/19/2012 14:11'!
project

	^self new project! !

!ConfigurationOfSomethingIt methodsFor: 'baselines' stamp: 'tomo 10/19/2012 15:28'!
baseline001: spec 
	<version: '0.0.1-baseline'>
	spec
		for: #common
		do: [spec blessing: #baseline.
			spec description: 'experimental baseline for SomethingIt'.
			spec repository: 'http://squeaksource.blueplane.jp/SomethingIt';
				
				package: 'SomethingIt'
				with: [spec requires: 'OSProcess'];
				
				package: 'OSProcess'
				with: [spec repository: 'http://www.squeaksource.com/OSProcess']]! !

!ConfigurationOfSomethingIt methodsFor: 'private' stamp: 'TO 10/19/2012 14:20'!
loadType
	"#atomic for dense dependents config. #linear for loose
	dependents. "
	^ #linear! !

!ConfigurationOfSomethingIt methodsFor: 'accessing' stamp: 'TO 10/19/2012 14:11'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: self loadType.
		project ]! !

!ConfigurationOfSomethingIt methodsFor: 'symbolic versions' stamp: 'TO 10/19/2012 14:21'!
stable: spec 
	<symbolicVersion: #stable>
	spec for: #common version: '0.0.1'! !

!ConfigurationOfSomethingIt methodsFor: 'versions' stamp: 'tomooda 10/19/2012 15:32'!
version001: spec 
	<version: '0.0.1' imports: #('0.0.1-baseline')>
	spec
		for: #common
		do: [spec blessing: #stable.
			spec description: 'Release 0.0.1'.
			spec author: 'tomooda'.
			spec timestamp: '10/19/2012 14:22'.
			spec package: 'SomethingIt' with: 'SomethingIt-tomooda.5';
				 package: 'OSProcess' with: 'OSProcess-dtl.71']! !
